@@ -1,31 +1,37 @@
 import os
 import re
 from pathlib import Path
+from typing import Dict, List
 
 from ..type_specs import HotkeysWithModes
 from ._base import Parser
-from .sources import Command, File, Manpage
+from .sources import Command, File, ManPage
 
 
 class Sxiv(Parser):
     required = bool(Command("sxiv"))
     sources = {
-        "default": [Manpage("sxiv")],
+        "default": [ManPage("sxiv")],
         "key_handler": [
-            File(Path(os.environ["XDG_CONFIG_HOME"]) / "sxiv" / "exec" / "key-handler")
+            File(
+                Path(os.environ.get("XDG_CONFIG_HOME", Path.home() / "/.config"))
+                / "sxiv"
+                / "exec"
+                / "key-handler"
+            )
         ],
     }
     has_modes = True
 
     @staticmethod
-    def _clean_action(string):
+    def _clean_action(string: str) -> str:
         return string.replace("\n", " ").strip()
 
     @staticmethod
-    def _clean_key(string):
+    def _clean_key(string: str) -> str:
         return string.replace(r"\-", "-").strip()
 
-    def parse(self, fetched) -> HotkeysWithModes:
+    def parse(self, fetched: Dict[str, List[str]]) -> HotkeysWithModes:
         content = fetched["default"][0]
         # to select section from manpage
         content_section = re.compile(r"\.SH KEYBOARD COMMANDS.*?\.SH", re.DOTALL)
